@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.16 2004/08/13 11:45:59 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.17 2004/08/25 08:44:55 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -329,7 +329,7 @@ static void write_pid_file(void)
 				   path, strerror(errno));
 		exit(1);
 	}
-	snprintf(pidbuf, sizeof(pidbuf), "%d", getpid());
+	snprintf(pidbuf, sizeof(pidbuf), "%d", (int)getpid());
 	fwrite(pidbuf, strlen(pidbuf), 1, fd);
 	if (fclose(fd))
 	{
