@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.21 2004/07/19 01:28:44 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.22 2004/08/13 11:47:51 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -279,7 +279,7 @@ extern void pool_disable_timeout(void);
 extern void pool_send_frontend_exits(POOL_CONNECTION_POOL *backend);
 
 extern int pool_read_message_length(POOL_CONNECTION_POOL *cp);
-extern char pool_read_kind(POOL_CONNECTION_POOL *cp);
+extern signed char pool_read_kind(POOL_CONNECTION_POOL *cp);
 
 extern POOL_STATUS SimpleForwardToFrontend(char kind, POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
 extern POOL_STATUS SimpleForwardToBackend(char kind, POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
